BusinessInsightsClient class

Constructors

BusinessInsightsClient(HttpHelper http)

Properties

hashCode int
The hash code for this object.
no setterinherited
http HttpHelper
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildCustomUrl(String prefix, List<String> segments) String
inherited
buildUrl(List<String> segments) String
inherited
getBusinessTiming(BusinessTimingRequest request, {RequestOptions? options}) Future<BusinessInsightsResponse>
getDepartmentCompatibility(BusinessMultipleRequest request, {RequestOptions? options}) Future<BusinessInsightsResponse>
getHiringCompatibility(BusinessMultipleRequest request, {RequestOptions? options}) Future<BusinessInsightsResponse>
getLeadershipStyle(BusinessSingleRequest request, {RequestOptions? options}) Future<BusinessInsightsResponse>
getSuccessionPlanning(BusinessMultipleRequest request, {RequestOptions? options}) Future<BusinessInsightsResponse>
getTeamDynamics(BusinessMultipleRequest request, {RequestOptions? options}) Future<BusinessInsightsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited