ProgressionReportRequest class

Inheritance

Constructors

ProgressionReportRequest({required Subject subject, required String targetDate, required ProgressionType progressionType, DateTimeLocation? location, ChartOptions? options, ReportOptions? reportOptions})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
location DateTimeLocation?
finalinherited
options ChartOptions?
finalinherited
progressionType ProgressionType
finalinherited
reportOptions ReportOptions?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject Subject
finalinherited
targetDate String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited