SolarReturnRequest class
- Implementers
Constructors
- SolarReturnRequest({required Subject subject, required int returnYear, DateTimeLocation? returnLocation, ChartOptions? options})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → ChartOptions?
-
final
- returnLocation → DateTimeLocation?
-
final
- returnYear → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → Subject
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited