TarotGlossaryParams class

Constructors

TarotGlossaryParams({String? arcana, String? suit, String? element, String? planet, String? sign, int? house})
const

Properties

arcana String?
final
element String?
final
hashCode int
The hash code for this object.
no setterinherited
house int?
final
planet String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sign String?
final
suit String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryParams() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited