WellnessInsightsClient class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- http → HttpHelper
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildCustomUrl(
String prefix, List< String> segments) → String -
inherited
-
buildUrl(
List< String> segments) → String -
inherited
-
getBiorhythms(
SingleSubjectRequest request, {RequestOptions? options}) → Future< InsightsResponse> -
getBodyMapping(
SingleSubjectRequest request, {RequestOptions? options}) → Future< InsightsResponse> -
getEnergyPatterns(
SingleSubjectRequest request, {RequestOptions? options}) → Future< InsightsResponse> -
getMoonWellness(
SingleSubjectRequest request, {RequestOptions? options}) → Future< InsightsResponse> -
getWellnessScore(
SingleSubjectRequest request, {RequestOptions? options}) → Future< InsightsResponse> -
getWellnessTiming(
SingleSubjectRequest request, {RequestOptions? options}) → Future< InsightsResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited