AstrologyClientConfig class
Constructors
- AstrologyClientConfig({String? apiKey, String? baseUrl, int timeout = defaultTimeoutMs, RetryConfig? retry, RequestOptions? requestOptions, bool debug = false, void logger(String, [dynamic])?})
-
const
Properties
- apiKey → String?
-
final
- baseUrl → String?
-
final
- debug → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → void Function(String, [dynamic])?
-
final
- requestOptions → RequestOptions?
-
final
- resolvedApiKey → String?
-
no setter
- resolvedBaseUrl → String
-
no setter
- retry → RetryConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited