PersonalHoroscopeRequest class
Constructors
- PersonalHoroscopeRequest({required Subject subject, String? date, Language? language, ReportTradition? tradition, HoroscopeTextFormat? format, bool? useEmoji})
-
const
Properties
- date → String?
-
final
- format → HoroscopeTextFormat?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → Language?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → Subject
-
final
- tradition → ReportTradition?
-
final
- useEmoji → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited