TransitChartRequest class
Constructors
-
TransitChartRequest({required Subject natalSubject, required DateTimeLocation transitDatetime, ChartOptions? options, Map<
String, dynamic> ? orbs}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- natalSubject → Subject
-
final
- options → ChartOptions?
-
final
-
orbs
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitDatetime → DateTimeLocation
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited